@@ -24,7 +24,7 @@
 
 # protocol to test the phenix protocol superpose_pdbs
 import os
-from pyworkflow.em.protocol.protocol_import import (ProtImportPdb,
+from pwem.protocols.protocol_import import (ProtImportPdb,
                                                     ProtImportVolumes)
 from phenix.protocols.protocol_superpose_pdbs import PhenixProtRunSuperposePDBs
 from pyworkflow.tests import *
@@ -166,8 +166,8 @@ class TestProtSuperposePdbs(TestImportData):
     def testSuperposePdbsFromPDBAndCIF(self):
         """ This test checks that phenix superpose_pdbs protocol runs with
         two atomic structures (pdb and cif)"""
-        print "Run phenix superpose_pdbs protocol from an imported pdb file " \
-              "and an imported cif file without volumes associated"
+        print("Run phenix superpose_pdbs protocol from an imported pdb file " \
+              "and an imported cif file without volumes associated")
 
         # import PDBs
         structure1_PDB = self._importStructurePDBWoVol()
@@ -198,8 +198,8 @@ class TestProtSuperposePdbs(TestImportData):
     def testSuperposePdbsFromPDBAndPDB(self):
         """ This test checks that phenix superpose_pdbs protocol runs with
         two atomic structures (pdbs)"""
-        print "Run phenix superpose_pdbs protocol from two imported pdb" \
-              "files without volumes associated"
+        print("Run phenix superpose_pdbs protocol from two imported pdb" \
+              "files without volumes associated")
 
         # import PDBs
         structure6_PDB = self._importStructureMolProbity1()
@@ -227,12 +227,52 @@ class TestProtSuperposePdbs(TestImportData):
         self.checkResults(startRMSD=0.464,
                           finalRMSD=0.462,
                           protSuperposePdbs=protSuperposePdbs)
+        ##################################################################
+        # superpose cif and pdb
+        args = {
+            'inputStructureFixed': structure6_PDB,
+            'inputStructureMoving': protSuperposePdbs.outputPdb
+        }
+
+        protSuperposePdbs2 = self.newProtocol(PhenixProtRunSuperposePDBs,
+                                             **args)
+        protSuperposePdbs2.setObjLabel('SuperposePDBs\n'
+                                      'no volumes associated to pdbs\n'
+                                       'cif and pdb')
+        self.launchProtocol(protSuperposePdbs2)
+        self.assertTrue(os.path.exists(
+            protSuperposePdbs2.outputPdb.getFileName()))
+
+        # check RMSD results
+        self.checkResults(startRMSD=0.462,
+                          finalRMSD=0.462,
+                          protSuperposePdbs=protSuperposePdbs2)
+        ##################################################################
+        # superpose pdb and cif
+        args = {
+            'inputStructureFixed': protSuperposePdbs.outputPdb,
+            'inputStructureMoving': structure7_PDB
+        }
+
+        protSuperposePdbs3 = self.newProtocol(PhenixProtRunSuperposePDBs,
+                                              **args)
+        protSuperposePdbs3.setObjLabel('SuperposePDBs\n'
+                                       'no volumes associated to pdbs\n'
+                                       'pdb and cif')
+        self.launchProtocol(protSuperposePdbs3)
+        self.assertTrue(os.path.exists(
+            protSuperposePdbs3.outputPdb.getFileName()))
+
+        # check RMSD results
+        self.checkResults(startRMSD=0.038,
+                          finalRMSD=0.0,
+                          protSuperposePdbs=protSuperposePdbs3)
 
     def testSuperposePdbsFromPDBAndCIFWithVol(self):
         """ This test checks that phenix superpose_pdbs protocol runs with
         two atomic structures (pdb and cif) with associated volumes"""
-        print "Run phenix superpose_pdbs protocol from an imported pdb file " \
-              "and a imported cif file with volumes associated"
+        print("Run phenix superpose_pdbs protocol from an imported pdb file " \
+              "and a imported cif file with volumes associated")
 
         # import PDBs
         structure2_PDB = self._importStructurePDBWithVol2()
@@ -267,9 +307,9 @@ class TestProtSuperposePdbs(TestImportData):
         """ This test checks that phenix superpose_pdbs protocol runs with
         two atomic structures (pdb with associated volumes and pdb without
         associated volume"""
-        print "Run phenix superpose_pdbs protocol from an imported pdb file " \
+        print("Run phenix superpose_pdbs protocol from an imported pdb file " \
               "with associated volume and an imported pdb without volume " \
-              "associated"
+              "associated")
 
         # import PDBs
         structure2_PDB = self._importStructurePDBWithVol2()
@@ -304,9 +344,9 @@ class TestProtSuperposePdbs(TestImportData):
         """ This test checks that phenix superpose_pdbs protocol runs with
         two atomic structures (pdb with associated volumes and pdb without
         associated volume"""
-        print "Run phenix superpose_pdbs protocol from an imported pdb file " \
+        print("Run phenix superpose_pdbs protocol from an imported pdb file " \
               "with associated volume and an imported pdb without volume " \
-              "associated"
+              "associated")
 
         # import PDBs
         structure2_PDB = self._importStructurePDBWithVol2()
@@ -341,9 +381,9 @@ class TestProtSuperposePdbs(TestImportData):
         """ This test checks that phenix superpose_pdbs protocol runs with
         two atomic structures (pdb with associated volumes and pdb without
         associated volume"""
-        print "Run phenix superpose_pdbs protocol from an imported pdb file " \
+        print("Run phenix superpose_pdbs protocol from an imported pdb file " \
               "with associated volume and an imported pdb without volume " \
-              "associated"
+              "associated")
 
         # import PDBs
         structure2_PDB = self._importStructurePDBWithVol2()
