@@ -24,8 +24,10 @@
 
 # protocol to test the phenix method real_spacerefine
 
-from pyworkflow.em.protocol.protocol_import import (ProtImportPdb,
+from pwem.protocols.protocol_import import (ProtImportPdb,
                                                     ProtImportVolumes)
+from pyworkflow import Config
+
 from phenix.protocols.protocol_real_space_refine import (PhenixProtRunRSRefine,
                                                          mmCIF)
 from phenix.protocols.protocol_molprobity import PhenixProtRunMolprobity
@@ -154,57 +156,78 @@ class TestValCryoEM(TestImportData):
     """
     def checkMPResults(self, ramOutliers, ramFavored, rotOutliers,
                        cbetaOutliers, clashScore, overallScore,
-                       protMolProbity, places=2):
+                       protMolProbity, places=2, delta=1):
         # method to check MolProbity statistic results of the Final Results
         # Table
-        self.assertAlmostEqual(protMolProbity.ramachandranOutliers,
-                               ramOutliers, places)
-        self.assertAlmostEqual(protMolProbity.ramachandranFavored,
-                               ramFavored, places)
-        self.assertAlmostEqual(protMolProbity.rotamerOutliers,
-                               rotOutliers, places)
-        self.assertAlmostEqual(protMolProbity.cbetaOutliers,
-                               cbetaOutliers, places)
-        self.assertAlmostEqual(protMolProbity.clashscore,
-                               clashScore, places)
-        self.assertAlmostEqual(protMolProbity.overallScore,
-                               overallScore, places)
+        try:
+            print("Checking ramOutliers")
+            self.assertAlmostEqual(protMolProbity.ramachandranOutliers.get(),
+                                   ramOutliers, delta=delta)
+            print("Checking ramFavored")
+            self.assertAlmostEqual(protMolProbity.ramachandranFavored.get(),
+                                   ramFavored, delta=delta)
+            print("Checking rotOutliers")
+            self.assertAlmostEqual(protMolProbity.rotamerOutliers.get(),
+                                   rotOutliers, delta=delta)
+            print("Checking cbetaOutliers")
+            self.assertAlmostEqual(protMolProbity.cbetaOutliers.get(),
+                                   cbetaOutliers, delta=delta)
+            print("Checking clashScore")
+            self.assertAlmostEqual(protMolProbity.clashscore.get(),
+                                   clashScore, delta=2)
+            print("Checking overallScore")
+            self.assertAlmostEqual(protMolProbity.overallScore.get(),
+                                   overallScore, delta=delta)
+        except Exception as e:
+            # print error since test does not print it
+            print(("Exception error:", str(e)))
+            raise self.failureException(str(e))
 
     def checkRSRefineResults(self, ramOutliers, ramFavored, rotOutliers,
                              cbetaOutliers, clashScore, overallScore,
-                             protRSRefine, places=2):
+                             protRSRefine, places=2, delta=1):
         # method to check Real Space Refine statistic results of the Final Results
         # Table
-        self.assertAlmostEqual(protRSRefine.ramachandranOutliers.get(),
-                               ramOutliers, places)
-        self.assertAlmostEqual(protRSRefine.ramachandranFavored.get(),
-                               ramFavored, delta=1)
-        self.assertAlmostEqual(protRSRefine.rotamerOutliers.get(),
-                               rotOutliers, delta=3)
-        self.assertAlmostEqual(protRSRefine.cbetaOutliers.get(),
-                               cbetaOutliers, places)
-        self.assertAlmostEqual(protRSRefine.clashscore.get(),
-                               clashScore, delta=0.5)
-        self.assertAlmostEqual(protRSRefine.overallScore.get(),
-                               overallScore, delta=0.5)
+        try:
+            self.assertAlmostEqual(protRSRefine.ramachandranOutliers.get(),
+                                   ramOutliers, places)
+            self.assertAlmostEqual(protRSRefine.ramachandranFavored.get(),
+                                   ramFavored, delta=1)
+            self.assertAlmostEqual(protRSRefine.rotamerOutliers.get(),
+                                   rotOutliers, delta=3)
+            self.assertAlmostEqual(protRSRefine.cbetaOutliers.get(),
+                                   cbetaOutliers, places)
+            self.assertAlmostEqual(protRSRefine.clashscore.get(),
+                                   clashScore, delta=1.5)
+            self.assertAlmostEqual(protRSRefine.overallScore.get(),
+                                   overallScore, delta=1.5)
+        except Exception as e:
+            # print error since test does not print it
+            print(("Exception error:", str(e)))
+            raise self.failureException(str(e))
 
     def checkValCryoEMResults(self, ramOutliers, ramFavored, rotOutliers,
                              cbetaOutliers, clashScore, overallScore,
                              protValCryoEM, places=2):
         # method to check Validation CryoEM statistic results of the Final Results
         # Table
-        self.assertAlmostEqual(protValCryoEM.ramachandranOutliers.get(),
-                               ramOutliers, places)
-        self.assertAlmostEqual(protValCryoEM.ramachandranFavored.get(),
-                               ramFavored, delta=1)
-        self.assertAlmostEqual(protValCryoEM.rotamerOutliers.get(),
-                               rotOutliers, delta=3)
-        self.assertAlmostEqual(protValCryoEM.cbetaOutliers.get(),
-                               cbetaOutliers, places)
-        self.assertAlmostEqual(protValCryoEM.clashscore.get(),
-                               clashScore, delta=0.5)
-        self.assertAlmostEqual(protValCryoEM.overallScore.get(),
-                               overallScore, delta=0.5)
+        try:
+            self.assertAlmostEqual(protValCryoEM.ramachandranOutliers.get(),
+                                   ramOutliers, places)
+            self.assertAlmostEqual(protValCryoEM.ramachandranFavored.get(),
+                                   ramFavored, delta=1)
+            self.assertAlmostEqual(protValCryoEM.rotamerOutliers.get(),
+                                   rotOutliers, delta=3)
+            self.assertAlmostEqual(protValCryoEM.cbetaOutliers.get(),
+                                   cbetaOutliers, places)
+            self.assertAlmostEqual(protValCryoEM.clashscore.get(),
+                                   clashScore, delta=1.5)
+            self.assertAlmostEqual(protValCryoEM.overallScore.get(),
+                                   overallScore, delta=1.5)
+        except Exception as e:
+            # print error since test does not print it
+            print(("Exception error:", str(e)))
+            raise self.failureException(str(e))
 
     def testValCryoEMFromPDB(self):
         """ This test checks that phenix real space refine protocol runs
@@ -355,7 +378,8 @@ class TestValCryoEM(TestImportData):
                   "command_line/validation_cryoem.py' does not exists.\n"
                   "Check if you need to upgrade your PHENIX version to run "
                   "VALIDATION_CRYOEM.\nYour current PHENIX version is 1.13.\n"
-                  "Check configuration file: ~/.config/scipion/scipion.conf\n"
+                  "Check configuration file: " +
+                  Config.SCIPION_LOCAL_CONFIG + "\n"
                   "and set VALIDATION_CRYOEM and PHENIX_HOME variables properly.\n"
                   "Current values:\nPHENIX_HOME = /usr/local/phenix-1.13-2998\n")
 
@@ -490,7 +514,8 @@ class TestValCryoEM(TestImportData):
                             "command_line/validation_cryoem.py' does not exists.\n"
                             "Check if you need to upgrade your PHENIX version to run "
                             "VALIDATION_CRYOEM.\nYour current PHENIX version is 1.13.\n"
-                            "Check configuration file: ~/.config/scipion/scipion.conf\n"
+                            "Check configuration file: " +
+                            Config.SCIPION_LOCAL_CONFIG + "\n"
                             "and set VALIDATION_CRYOEM and PHENIX_HOME variables properly.\n"
                             "Current values:\nPHENIX_HOME = /usr/local/phenix-1.13-2998\n")
 
@@ -498,11 +523,11 @@ class TestValCryoEM(TestImportData):
         # self.assertTrue(False)
 
         self.checkValCryoEMResults(ramOutliers=0.00,
-                                  ramFavored=96.11,
-                                  rotOutliers=3.04,
+                                  ramFavored=95.41,
+                                  rotOutliers=3.47,
                                   cbetaOutliers=0,
-                                  clashScore=5.30,
-                                  overallScore=1.92,
+                                  clashScore=4.75,
+                                  overallScore=1.98,
                                   protValCryoEM=protValCryoEM)
 
     def testValCryoEMFFromVolumeAssociatedToPDB3(self):
@@ -594,11 +619,12 @@ class TestValCryoEM(TestImportData):
         else:
             self.checkMPResults(ramOutliers=0.00,
                                 ramFavored=94.42,
-                                rotOutliers=11.04,
+                                rotOutliers=12.96,
                                 cbetaOutliers=0,
                                 clashScore=12.96,
                                 overallScore=2.80,
                                 protMolProbity=protMolProbity2)
+        # TODO: Talk to Roberto if we have to continue testing these values (rotOutliers)
 
         # validation_cryoEM
         args = {
@@ -617,7 +643,8 @@ class TestValCryoEM(TestImportData):
                             "command_line/validation_cryoem.py' does not exists.\n"
                             "Check if you need to upgrade your PHENIX version to run "
                             "VALIDATION_CRYOEM.\nYour current PHENIX version is 1.13.\n"
-                            "Check configuration file: ~/.config/scipion/scipion.conf\n"
+                            "Check configuration file: " +
+                            Config.SCIPION_LOCAL_CONFIG + "\n"
                             "and set VALIDATION_CRYOEM and PHENIX_HOME variables properly.\n"
                             "Current values:\nPHENIX_HOME = /usr/local/phenix-1.13-2998\n")
 
@@ -629,8 +656,8 @@ class TestValCryoEM(TestImportData):
                                   ramFavored=94.42,
                                   rotOutliers=11.04,
                                   cbetaOutliers=0,
-                                  clashScore=12.92,
-                                  overallScore=2.79,
+                                  clashScore=12.96,
+                                  overallScore=2.80,
                                   protValCryoEM=protValCryoEM)
 
     def testValCryoEMFFromVolumeAndPDB4(self):
@@ -753,7 +780,8 @@ class TestValCryoEM(TestImportData):
                             "command_line/validation_cryoem.py' does not exists.\n"
                             "Check if you need to upgrade your PHENIX version to run "
                             "VALIDATION_CRYOEM.\nYour current PHENIX version is 1.13.\n"
-                            "Check configuration file: ~/.config/scipion/scipion.conf\n"
+                            "Check configuration file: " +
+                            Config.SCIPION_LOCAL_CONFIG + "\n"
                             "and set VALIDATION_CRYOEM and PHENIX_HOME variables properly.\n"
                             "Current values:\nPHENIX_HOME = /usr/local/phenix-1.13-2998\n")
 
