@@ -27,28 +27,28 @@
 
 import collections
 import json
-import os
-import glob
 from phenix import PHENIXVERSION
 import matplotlib.pyplot as plt
-from tkMessageBox import showerror
+from tkinter import *
+from tkinter import messagebox
 from pyworkflow.viewer import DESKTOP_TKINTER, WEB_DJANGO, ProtocolViewer
-from pyworkflow.em.viewers import TableView, Chimera
+from pwem.viewers import TableView, Chimera
 from pyworkflow.protocol.params import LabelParam, EnumParam
-from pyworkflow.utils import importFromPlugin
 from phenix import Plugin
 from pyworkflow.tests import *
-from pyworkflow.em.data import String
+from pwem.objects import String
+from pwem import Domain
+from collections.abc import ValuesView
 
 def errorWindow(tkParent, msg):
     try:
         # if tkRoot is null the error message may be behind
         # other windows
-        showerror("Error",  # bar title
-                  msg,  # message
-                  parent=tkParent)
+        messagebox.showerror("Error",  # bar title
+                              msg,  # message
+                              parent=tkParent)
     except:
-        print("Error:", msg)
+        print(("Error:", msg))
 
 
 class PhenixProtRefinementBaseViewer(ProtocolViewer):
@@ -232,7 +232,7 @@ class PhenixProtRefinementBaseViewer(ProtocolViewer):
                                 '(sorted by deviation)')
             if (self.dictOverall['_protein'] == True):
                 group = form.addGroup('Protein')
-                self.plotList = [u'Ramachandran plot', u'Chi1-Chi2 plot']
+                self.plotList = ['Ramachandran plot', 'Chi1-Chi2 plot']
                 group.addParam('plotType', EnumParam,
                                 choices=self.plotList, default=0,
                                 label="Select plot:",
@@ -443,15 +443,15 @@ class PhenixProtRefinementBaseViewer(ProtocolViewer):
                                  "the N highest peaks in the model-calculated "
                                  "map and the N highest peaks in the "
                                  "experimental map.\n")
-                self.residueTypeList = [u'Protein', u'Other', u'Water',
-                                        u'Everything']
+                self.residueTypeList = ['Protein', 'Other', 'Water',
+                                        'Everything']
                 group.addParam('residueType', EnumParam,
                                 choices=self.residueTypeList, default=0,
                                 label="Residue Type:",
                                 help="Select a residue Type. Protein is chosen by "
                                  "default.\n")
-                self.ccBelowList = [u'0.1', u'0.2', u'0.3', u'0.4', u'0.5', u'0.6',
-                                    u'0.7', u'0.8', u'0.9', u'1.0']
+                self.ccBelowList = ['0.1', '0.2', '0.3', '0.4', '0.5', '0.6',
+                                    '0.7', '0.8', '0.9', '1.0']
                 group.addParam('ccIndex', EnumParam,
                                 choices=self.ccBelowList, default=7,
                                 label="Show CC below:",
@@ -579,8 +579,7 @@ class PhenixProtRefinementBaseViewer(ProtocolViewer):
         }
 
     def _displayMapModel(self, e=None):
-        bildFileName = os.path.abspath(self.protocol._getTmpPath(
-            "axis_output.bild"))
+        bildFileName = self.protocol._getTmpPath("axis_output.bild")
         try:
             _inputVol = self.protocol.inputVolume.get()
         except:
@@ -601,6 +600,10 @@ class PhenixProtRefinementBaseViewer(ProtocolViewer):
         counter = 0
         fnCmd = self.protocol._getTmpPath("chimera_output.cmd")
         f = open(fnCmd, 'w')
+        # change to workingDir
+        # If we do not use cd and the project name has an space
+        # the protocol fails even if we pass absolute paths
+        f.write('cd %s\n' % os.getcwd())
         # reference axis model = 0
         f.write("open %s\n" % bildFileName)
         f.write("cofr 0,0,0\n")  # set center of coordinates
@@ -610,15 +613,15 @@ class PhenixProtRefinementBaseViewer(ProtocolViewer):
         if self._getInputVolume() is not None:
             fnVol = self._getInputVolume()
             try:
-                VOLUMEFILENAME = os.path.abspath(self.protocol._getExtraPath(
-                    self.protocol.MOLPROBITYFILE))
+                VOLUMEFILENAME = self.protocol._getExtraPath(
+                    self.protocol.MOLPROBITYFILE)
             except:
                 if self.protocol.hasAttribute('REALSPACEFILE'):
-                    VOLUMEFILENAME = os.path.abspath(self.protocol._getExtraPath(
-                        self.protocol.REALSPACEFILE))
+                    VOLUMEFILENAME = self.protocol._getExtraPath(
+                        self.protocol.REALSPACEFILE)
                 elif self.protocol.hasAttribute('VALIDATIONCRYOEMFILE'):
-                    VOLUMEFILENAME = os.path.abspath(self.protocol._getExtraPath(
-                        self.protocol.VALIDATIONCRYOEMFILE))
+                    VOLUMEFILENAME = self.protocol._getExtraPath(
+                        self.protocol.VALIDATIONCRYOEMFILE)
 
             f.write("open %s\n" % VOLUMEFILENAME)
             x, y, z = fnVol.getOrigin(force=True).getShifts()
@@ -629,10 +632,10 @@ class PhenixProtRefinementBaseViewer(ProtocolViewer):
             if len(fnVol.getHalfMaps()) > 0:
                 for halfMap in fnVol.getHalfMaps().split(','):
                     counter += 1
-                    if not os.path.abspath(halfMap).endswith(".mrc"):
-                        f.write("open %s\n" % (os.path.abspath(halfMap).split(".")[0] + ".mrc"))
+                    if not halfMap.endswith(".mrc"):
+                        f.write("open %s\n" % halfMap.split(".")[0] + ".mrc")
                     else:
-                        f.write("open %s\n" % os.path.abspath(halfMap))
+                        f.write("open %s\n" % halfMap)
                     f.write("volume#%d style surface voxelSize %f\n" %
                             (counter, sampling))
                     f.write("volume#%d origin %0.2f,%0.2f,%0.2f\n" %
@@ -640,22 +643,21 @@ class PhenixProtRefinementBaseViewer(ProtocolViewer):
 
         # input PDB (usually from coot)
         counter += 1  # 2
-        pdbFileName = os.path.abspath(
-            self.protocol.inputStructure.get().getFileName())
+        pdbFileName = self.protocol.inputStructure.get().getFileName()
         f.write("open %s\n" % pdbFileName)
 
         # refined PDB
         if self.protocol.hasAttribute('outputPdb') and \
                 (len(os.listdir(self.protocol._getExtraPath())) > 5):
             counter += 1  # 3
-            pdbFileName = os.path.abspath(
-                self.protocol.outputPdb.getFileName())
+            pdbFileName = self.protocol.outputPdb.getFileName()
             f.write("open %s\n" % pdbFileName)
 
         f.close()
         # run in the background
-        chimeraPlugin = importFromPlugin('chimera', 'Plugin', doRaise=True)
-        chimeraPlugin.runChimeraProgram(chimeraPlugin.getProgram(), fnCmd + "&")
+        chimeraPlugin = Domain.importFromPlugin('chimera', 'Plugin', doRaise=True)
+        chimeraPlugin.runChimeraProgram(chimeraPlugin.getProgram(), fnCmd + "&",
+                                        cwd=os.getcwd())
         return []
 
     def _visualizeMolProbityResults(self, e=None):
@@ -678,7 +680,7 @@ class PhenixProtRefinementBaseViewer(ProtocolViewer):
         else:
             pdb = self.protocol.inputStructure.get()
 
-        CootRefine = importFromPlugin('ccp4.protocols', 'CootRefine', doRaise=True)
+        CootRefine = Domain.importFromPlugin('ccp4.protocols', 'CootRefine', doRaise=True)
         project = self.protocol.getProject()
 
         args = {
@@ -932,7 +934,7 @@ class PhenixProtRefinementBaseViewer(ProtocolViewer):
 
     def _showResults(self, headerList, dictX, val, mesg, title):
         dataList = []
-        for k, v in dictX.iteritems():
+        for k, v in list(dictX.items()):
             if k[0] == "_":
                 continue
             if isinstance(v, int):
@@ -1042,10 +1044,10 @@ class PhenixProtRefinementBaseViewer(ProtocolViewer):
                             self._parseFileAtom1Atom2(words, f)
                             self.dictBLRestraints['Number of outliers '\
                                                   '> 4sigma'] = len(self.Atom1)
-                            self.blDataList = zip(self.Atom1, self.Atom2,
-                                                  self.IdealValue,
-                                                  self.ModelValue,
-                                                  self.Deviation)
+                            self.blDataList = list(zip(self.Atom1, self.Atom2,
+                                                       self.IdealValue,
+                                                       self.ModelValue,
+                                                       self.Deviation))
 
                     elif (words[0] == 'angle' or words[0] == 'Angle' and words[1] == ':'):
                         self.dictBARestraints['Number of restraints'] = int(
@@ -1591,12 +1593,12 @@ if data.ramalyze is not None:
         else:
             for i in range(len(listL)):
                 if listL[i][5] <= float(self.ccBelowList[decimal_index]):
-                    self.RSCCList.append((unicode(listL[i][0]),
-                                          unicode(listL[i][1]),
-                                          unicode(listL[i][2]),
-                                          unicode(listL[i][3]),
-                                          unicode(listL[i][4]),
-                                          unicode(listL[i][5])))
+                    self.RSCCList.append((str(listL[i][0]),
+                                          str(listL[i][1]),
+                                          str(listL[i][2]),
+                                          str(listL[i][3]),
+                                          str(listL[i][4]),
+                                          str(listL[i][5])))
 
 
 
